<?php

/*
 * This file is part of the PHPBench package
 *
 * (c) Daniel Leech <daniel@dantleech.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace PhpBench\Console\Command\Handler;

use PhpBench\Expression\Parser;
use PhpBench\Model\SuiteCollection;
use PhpBench\Registry\Registry;
use PhpBench\Serializer\XmlDecoder;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;

class SuiteCollectionHandler
{
    private $xmlDecoder;
    private $parser;
    private $storage;

    public function __construct(
        XmlDecoder $xmlDecoder,
        Parser $parser,
        Registry $storage
    ) {
        $this->xmlDecoder = $xmlDecoder;
        $this->parser = $parser;
        $this->storage = $storage;
    }

    public static function configure(Command $command)
    {
        $command->addOption('file', null, InputOption::VALUE_REQUIRED | InputOption::VALUE_IS_ARRAY, 'Report XML file');
        $command->addOption('query', null, InputOption::VALUE_REQUIRED | InputOption::VALUE_IS_ARRAY, 'Storage query');
    }

    public function suiteCollectionFromInput(InputInterface $input)
    {
        $files = $input->getOption('file');
        $queries = $input->getOption('query');

        if (!$files && !$queries) {
            throw new \InvalidArgumentException(
                'You must specify at least one result --file (generated by the run command\'s `--dump-file=` option)'
            );
        }

        $collection = new SuiteCollection();

        if ($files) {
            $collection->mergeCollection(
                $this->xmlDecoder->decodeFiles($files)
            );
        }

        if ($queries) {
            foreach ($queries as $query) {
                $constraint = $this->parser->parse($query);
                $collection->mergeCollection(
                    $this->storage->getService()->query($constraint)
                );
            }
        }

        return $collection;
    }
}
